Keen | List - Columns 1
Description: List columns page example

# Customer Relationship Management

New Order

### Users

450 Total
Selected:
Add User
Luke Davids Angular Developer
Progress 40
chat profile
Lisa Moss QA Manager
Progress 40
chat profile
Matt Pears Head of Development
Progress 70
chat profile
Jordan James Web Designer
Progress 60
chat profile
Peter Brown CTO
Progress 80
chat profile
Jason Muller Python Developer
Progress 40
chat profile
Lisa Moss Account Manager
Progress 80
chat profile
Megan Higgins Sales Manager
Progress 30
chat profile
Ana Larson Art Director
Progress 90
chat profile
Luke Davids Angular Developer
Progress 40
chat profile
Chelsea Hughes Web Designer
Progress 70
chat profile
Benjamin Fox System Architect
Progress 60
chat profile
Arnold Kim Angular Developer
Progress 40
chat profile
Karl Hugo Product Manager
Progress 70
chat profile
Ben Stiller Software Architect
Progress 60
chat profile

- ...
- 29
- 30
- 32
- 34
- ...

10 of 230

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!